	* Close Competitors? Bilateral Bank Competition and Spatial Variation in Firms' Access to Credit
	* Ralph De Haas, Liping Lu and Steven Ongena (2023)
		
	cls 
	clear

	gl root "" // Update accordingly
	gl joeg "" // Parent folder of "Codes", "Data" and "Results"
	cd "$joeg\Results" // Location to save results
	
	* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	**# Import data, set globals for regressions and export settings
	* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~	

	use "$joeg\Data\BEEPSV-BEPS_analysis_INTERNAL.dta", clear
	
	tab ind, gen(ind)
	tab ct, gen(ct)
	
	* Main regressions
	gl cont_firm1 	large1 public_company sole_proprietorship exporter ext_audit old
	gl FE 			ind1-ind6  ct1-ct19
	gl FEind		ind1-ind6
	gl FEctry		ct1-ct19
	gl controls 	$cont_firm1 $FE gdp0709_w
	gl cont_loc 	hhi_locbr lerneri_locbr relbank lnnr_br10km
	
	* Checking stability of coef.
	gl c0
	gl c1 $cont_firm1 		// Firm level controls
	gl c2 ind1-ind6			// Ind FE
	gl c3 ct1-ct19			// Country FE
	gl c4 $c1 $c2 			// Firm controls + Ind FE
	gl c5 $c1 $c3 			// Firm controls + Country FE
	gl c6 $c1 $c2 $c3 		// Firm controls + Ind FE + Country FE
	gl c7 $c6 gdp0709_w
	gl c8 $c7 hhi_locbr lnnr_br10km	
	
	* To export the regressions directly to LaTeX
	gl opts "append tex(fragment) aster dec(3) rdec(3) adec(2) nonotes nodepvar ctitle(" ") label mfx addstat("Pseudo R2", e(r2_p))" 
	
	* Generate additional variables 
	gen logpopdensity30km = log(popdensity30km)
	lab var logpopdensity30km "Log population density"
	
	foreach var of varlist comp1_sme_ratio comp1_smetar_ratio comp1_smeac_ratio hhi_locbr lnnr_br10km lerneri_locbr relbank { // comp1_xbsme_ratio comp1_xbsmetar_ratio comp1_xbsmeac_ratio 
		local variable_label1 : variable label `var'
		gen large1`var' = large1*`var'
		lab var large1`var' "`variable_label1' x Large firm"
	}	

	
	
	*---------------------------------------------------------------------------
	**# Figure 1: export data to read into QGIS
	*---------------------------------------------------------------------------		
	
	preserve
	keep city country latitude longitude comp1_sme_ratio
	collapse (mean) latitude lon comp1_sme_ratio, by(country city)
	_pctile comp1_sme_ratio, p(25, 50, 75)
	gen 	group = 1 if comp1_sme_ratio<=`r(r1)'
	replace group = 2 if comp1_sme_ratio>`r(r1)' & comp1_sme_ratio<=`r(r2)'
	replace group = 3 if comp1_sme_ratio>`r(r2)' & comp1_sme_ratio<=`r(r3)'
	replace group = 4 if comp1_sme_ratio>`r(r3)'
	export delimited using "figure1data.csv", replace
	export delimited using "figure1data_1.csv" if group==1, replace
	export delimited using "figure1data_2.csv" if group==2, replace
	export delimited using "figure1data_3.csv" if group==3, replace
	export delimited using "figure1data_4.csv" if group==4, replace
	restore
	
	
	*---------------------------------------------------------------------------
	**# Table 1: summary statistics 
	*---------------------------------------------------------------------------	
	
	* Locality level summary statistics & variable labels 
	egen tag=tag(city country) 
	
	tabstat comp1_sme_ratio comp1_smetar_ratio comp1_smeac_ratio /// 
			forbank glcfpar_locbr relbank shsmall_bank_locba tier1_locbr tier1par_locbr  /// 
			hhi_locbr lnnr_br10km lnnr_ba10km lerneri_locbr share_state_loc /// 
			glcf_2007_locbr glcfpar_2007_locbr delta07to12_nlpar_01 ///
			if tag==1 ///
			, stat(n mean median sd min p25 p75 max) col(stat) 
		
	des comp1_sme_ratio comp1_smetar_ratio comp1_smeac_ratio /// 
		forbank glcfpar_locbr relbank shsmall_bank_locba tier1_locbr tier1par_locbr  /// 
		hhi_locbr lnnr_br10km lnnr_ba10km lerneri_locbr share_state_loc /// 
		glcf_2007_locbr glcfpar_2007_locbr delta07to12_nlpar_01
	  
	* Firm level summary statistics 
	tabstat constrained_1 constrained_2 constrained_4 inputs_credit  /// 
			$cont_firm1 loan_needed_both subsidized informal ///
			, stat(n mean median sd min p25 p75 max) col(stat)

	des constrained_1 constrained_2 constrained_4 inputs_credit  /// 
		$cont_firm1 loan_needed_both subsidized informal ///
 
 
	*---------------------------------------------------------------------------
	**# Table 2: baseline credit constaint	
	*---------------------------------------------------------------------------

	eststo clear
	estimates clear
	foreach x in comp1_sme_ratio comp1_smetar_ratio comp1_smeac_ratio  { // 
		probit constrained_1 `x' $controls, iter(150) tech(bfgs) vce(cluster GADM_1)
		mfx
		outreg2 using "temp.tex", drop($controls) $opts
		cap drop e
		gen e=e(sample)
	}
	
	foreach x in hhi_locbr lerneri_locbr  relbank lnnr_br10km lnnr_ba10km   {
		probit constrained_1 `x' $controls if e, iter(150) tech(bfgs) vce(cluster GADM_1)
		mfx
		outreg2 using "temp.tex", drop($controls) $opts
	}

	foreach x in comp1_sme_ratio comp1_smetar_ratio comp1_smeac_ratio {
		probit constrained_1 `x' $cont_loc  $controls, iter(150) tech(bfgs) vce(cluster GADM_1)
		mfx
		outreg2 using "temp.tex", drop($controls) $opts sortvar(comp1_sme_ratio comp1_smetar_ratio comp1_smeac_ratio hhi_locbr lerneri_locbr relbank lnnr_br10km lnnr_ba10km)
	}	

	filefilter "temp.tex" "temp_1.tex", from(" &  &  &  &  &  &  &  &  &  &  &  \BS\BS") to("") replace	
	filefilter "temp_1.tex" "temp_2.tex", from("VARIABLES") to("") replace	
	filefilter "temp_2.tex" "temp_3.tex", from("\BSbegin{tabular}{lccccccccccc} \BShline") to("") replace	
	filefilter "temp_3.tex" "temp_4.tex", from("Observations") to("\BShline Observations") replace		
	filefilter "temp_4.tex" "Table2_baseline.tex", from("\BSend{tabular}") to("") replace	
	
	local files : dir "$joeg\Results" files "temp*"
	foreach file in `files' {
		di "`file'"
		cap erase "`file'"
	}
				
		
	*---------------------------------------------------------------------------
	**# Table 3: Large firm effect
	*---------------------------------------------------------------------------	
	
	gl loc_large hhi_locbr large1hhi_locbr lnnr_br10km large1lnnr_br10km lerneri_locbr large1lerneri_locbr relbank large1relbank
	
	eststo clear	
	estimates clear
	foreach x in comp1_sme_ratio comp1_smetar_ratio comp1_smeac_ratio {
		probit constrained_1 `x' large1`x' $cont_loc $controls , iter(150) tech(bfgs) vce(cluster GADM_1)
		mfx
		outreg2 using "temp.tex", drop($controls $cont_loc)  $opts
	}
	foreach x in comp1_sme_ratio comp1_smetar_ratio comp1_smeac_ratio {
		probit constrained_1 `x' large1`x' $loc_large $controls, iter(150) tech(bfgs) vce(cluster GADM_1)
		mfx
		outreg2 using "temp.tex", drop($controls $loc_large)  $opts
	}
		

	filefilter "temp.tex" "temp_1.tex", from(" &  &  &  &  &  &  \BS\BS") to("") replace	
	filefilter "temp_1.tex" "temp_2.tex", from("VARIABLES") to("") replace	
	filefilter "temp_2.tex" "temp_3.tex", from("\BSbegin{tabular}{lcccccc} \BShline") to("") replace	
	filefilter "temp_3.tex" "temp_4.tex", from("Observations") to("\BShline Observations") replace	
	filefilter "temp_4.tex" "Table3_largefirm.tex", from("\BSend{tabular}") to("") replace	
	
	local files : dir "$joeg\Results" files "temp*"
	foreach file in `files' {
		di "`file'"
		cap erase "`file'"
	}
		
	foreach x in comp1_sme_ratio comp1_smetar_ratio comp1_smeac_ratio {
		
		qui: probit constrained_1 `x' large1`x' $controls $cont_loc, iter(150) tech(bfgs) vce(cluster GADM_1)
		di "Bilaterial comp: `x', with local controls"
		test `x' + large1`x' = 0

	}
	
	foreach x in comp1_sme_ratio comp1_smetar_ratio comp1_smeac_ratio {
		
		qui: probit constrained_1 `x' large1`x' $controls $loc_large, iter(150) tech(bfgs) vce(cluster GADM_1)
		di "Bilaterial comp: `x', with local controls x large"
		test `x' + large1`x' = 0

	}	

	*---------------------------------------------------------------------------
	**# Table 4: Coefficient stability
	*---------------------------------------------------------------------------	
	
	eststo clear
	estimates clear
	probit constrained_1 comp1_sme_ratio, iter(150) tech(bfgs) vce(cluster GADM_1) 
	mfx
	outreg2 using "temp.tex", $opts addtext(\hline Country FE, No, Industry FE, No, Firm covariates, No) 
		
	probit constrained_1 comp1_sme_ratio 				ct1-ct19, iter(150) tech(bfgs) vce(cluster GADM_1) 
	mfx
	outreg2 using "temp.tex", $opts addtext(\hline Country FE, Yes, Industry FE, No, Firm covariates, No) drop(ct*)
		
	probit constrained_1 comp1_sme_ratio ind1-ind6 	ct1-ct19, iter(150) tech(bfgs) vce(cluster GADM_1) 
	mfx
	outreg2 using "temp.tex", $opts addtext(\hline Country FE, Yes, Industry FE, Yes, Firm covariates, No) drop(ct* ind*)
			
	probit constrained_1 comp1_sme_ratio  $cont_firm1 	ct1-ct19 ind1-ind6, iter(150) tech(bfgs) vce(cluster GADM_1) 
	mfx
	outreg2 using "temp.tex", $opts addtext(\hline Country FE, Yes, Industry FE, Yes, Firm covariates, Yes) drop(ct* $cont_firm1 ind*)	
	
	probit constrained_1 comp1_sme_ratio $cont_loc $cont_firm1	ct1-ct19 ind1-ind6, iter(150) tech(bfgs) vce(cluster GADM_1) 
	mfx
	outreg2 using "temp.tex", $opts addtext(\hline Country FE, Yes, Industry FE, Yes, Firm covariates, Yes) drop(ct* $cont_firm1 ind*)		
				
	probit constrained_1 comp1_sme_ratio $cont_loc gdp0709_w $cont_firm1	ct1-ct19 ind1-ind6, iter(150) tech(bfgs) vce(cluster GADM_1) 
	mfx
	outreg2 using "temp.tex", $opts addtext(\hline Country FE, Yes, Industry FE, Yes, Firm covariates, Yes) drop(ct* $cont_firm1 ind*)						
	
	probit constrained_1 comp1_sme_ratio $cont_loc gdp0709_w gdp_regional2009 $cont_firm1	ct1-ct19 ind1-ind6, iter(150) tech(bfgs) vce(cluster GADM_1) 
	mfx
	outreg2 using "temp.tex", $opts addtext(\hline Country FE, Yes, Industry FE, Yes, Firm covariates, Yes) drop(ct* $cont_firm1 ind*)	

	probit constrained_1 comp1_sme_ratio $cont_loc gdp0709_w gdp_regional2009 logpopdensity30km $cont_firm1 	ct1-ct19 ind1-ind6, iter(150) tech(bfgs) vce(cluster GADM_1) 
	mfx
	outreg2 using "temp.tex", $opts addtext(\hline Country FE, Yes, Industry FE, Yes, Firm covariates, Yes) drop(ct* $cont_firm1 ind*)
		
	filefilter "temp.tex" "temp_1.tex", from(" &  &  &  &  &  &  &  &  \BS\BS") to("") replace	
	filefilter "temp_1.tex" "temp_2.tex", from("VARIABLES") to("") replace	
	filefilter "temp_2.tex" "temp_3.tex", from("\BSbegin{tabular}{lcccccccc} \BShline") to("") replace	
	filefilter "temp_3.tex" "temp_4.tex", from("Observations") to("\BShline Observations") replace	
	filefilter "temp_4.tex" "Table4_stability.tex", from("\BSend{tabular}") to("") replace	
	
	local files : dir "$joeg\Results" files "temp*"
	foreach file in `files' {
		di "`file'"
		cap erase "`file'"
	}		

	
	*---------------------------------------------------------------------------
	**# Table 5: Robustness -- Locality coveraites
	*---------------------------------------------------------------------------
	
	eststo clear
	estimates clear
	foreach x in glcfpar_locbr tier1_locbr tier1par_locbr forbank glcf_2007_locbr delta07to12_nlpar_01 shsmall_bank_locba relbank lerneri_locbr share_state_loc {
		probit constrained_1 comp1_sme_ratio `x' $controls, iter(150) tech(bfgs) vce(cluster GADM_1)
		mfx
		outreg2 using "temp.tex", drop($controls) $opts			
	}
	
	probit constrained_1 comp1_sme_ratio glcfpar_locbr delta07to12_nlpar_01 tier1par_locbr forbank shsmall_bank_locba relbank lerneri_locbr share_state_loc $controls, iter(150) tech(bfgs) vce(cluster GADM_1)
	mfx
	outreg2 using "temp.tex", drop($controls) $opts
	
	filefilter "temp.tex" "temp_1.tex", from(" &  &  &  &  &  &  &  &  &  &  &  \BS\BS") to("") replace	
	filefilter "temp_1.tex" "temp_2.tex", from("VARIABLES") to("") replace	
	filefilter "temp_2.tex" "temp_3.tex", from("\BSbegin{tabular}{lccccccccccc} \BShline") to("") replace	
	filefilter "temp_3.tex" "temp_5.tex", from("Observations") to("\BShline Observations") replace		
	filefilter "temp_5.tex" "Table5_localitycoveriates.tex", from("\BSend{tabular}") to("") replace	
	
	local files : dir "$joeg\Results" files "temp*"
	foreach file in `files' {
		di "`file'"
		cap erase "`file'"
	}		
	
	

	*---------------------------------------------------------------------------
	**# Table A3: Robustness -- alternative credit constrained variables
	*---------------------------------------------------------------------------
	
	eststo clear
	estimates clear
	foreach y in  constrained_2 constrained_4 inputs_credit {
		foreach x in comp1_sme_ratio  {
			probit `y' `x' 	$cont_loc $controls , iter(150) tech(bfgs) vce(cluster GADM_1)
			mfx
			outreg2 using "temp.tex", drop($controls) $opts
		}
	}
	
	filefilter "temp.tex" "temp_1.tex", from(" &  &  &  \BS\BS") to("") replace	
	filefilter "temp_1.tex" "temp_2.tex", from("VARIABLES") to("") replace	
	filefilter "temp_2.tex" "temp_3.tex", from("\BSbegin{tabular}{lccc} \BShline") to("") replace	
	filefilter "temp_3.tex" "temp_4.tex", from("Observations") to("\BShline Observations") replace
	filefilter "temp_4.tex" "TableA3_alternativecreditconst.tex", from("\BSend{tabular}") to("") replace	
	
	local files : dir "$joeg\Results" files "temp*"
	foreach file in `files' {
		di "`file'"
		cap erase "`file'"
	}
	
			
	*** ANNEX	
	

	*---------------------------------------------------------------------------
	**# Table OA1. Correlation matrix, net of country FE
	*---------------------------------------------------------------------------		
	
	* Residulise ouctomes, controling for country dummies
	foreach y in constrained_1 constrained_2 constrained_4 inputs_credit comp1_sme_ratio comp1_smetar_ratio comp1_smeac_ratio forbank glcf_2007_locbr glcfpar_2007_locbr glcfpar_locbr relbank tier1_locbr tier1par_locbr shsmall_bank_locba share_state_loc hhi_locbr lnnr_locba lnnr_locbr lerneri_locbr large1 public_company sole_proprietorship exporter ext_audit old {
	
		reg `y' ct1-ct19
		predict `y'_res, residuals
		local variable_label : variable label `y'
		label variable `y'_res `"`variable_label'"'
	
	}
		
	
	asdoc pwcorr *_res, star(all) replace nonum	label dec(3) save(TableOA1_correlations.doc)
		
		
	*---------------------------------------------------------------------------
	**#  Table OA3: Locality level reg with F-test
	*---------------------------------------------------------------------------			
	
	* Linear estimates, locality level averages 
	preserve
	foreach v of var * {
			local l`v' : variable label `v'
				if `"`l`v''"' == "" {
				local l`v' "`v'"
			}
	}	
		
	bys ct city: egen indmode=mode(ind)
	collapse (mean) comp1_sme_ratio comp1_smetar_ratio comp1_smeac_ratio hhi_locbr lnnr_locbr lnnr_locba lerneri_locbr relbank ///
					$cont_firm1 $FEind informal latitude longitude ind ///
			 (firstnm) indmode if constrained_1!=., by(ct city)
	
	foreach v of var * {
        label var `v' "`l`v''"
}
	tab ct, gen(ct_)
	
	lab var large1 "Large firm (local)"
	lab var public_company "Public firm (local)"
	lab var sole_proprietorship "Proprietorship (local)"
	lab var exporter "Exporter (local)"
	lab var ext_audit "Audited firm (local)"
	lab var old "Mature firm (local)"
	lab var informal "Informal payment (local)"
	
	gl cont_firm2 large1 informal sole_proprietorship exporter ext_audit
	
	* Firm covariates 
	eststo clear
	foreach y in comp1_smetar_ratio hhi_locbr lnnr_locbr lnnr_locba { 
		eststo `y': reg `y'  $cont_firm2 ct_*, vce(cluster ct)
				test $cont_firm2
				estadd scalar Ftest = r(p)
	}

	estadd local ctryFE "Yes": comp1_smetar_ratio hhi_locbr lnnr_locbr lnnr_locba

	noi esttab * using "TableOA3_localitylevel_ftest.tex", replace ///
		keep($cont_firm2) b(%9.4f) se(%9.4f) f nonum nolines ///
		stats(r2 N ctryFE Ftest, fmt(3 %15.0fc 0 3) /// 
		labels("\hline \addlinespace[1ex] R-squared" "Observations" "\hline \addlinespace[1ex] Country FE"  "\hline \addlinespace[1ex] \textit{p}-value of Wald test")) ///
		label nomtitles style(tex) nogaps nonotes star(* .1 ** .05 *** .01)	
	restore		
	


	*---------------------------------------------------------------------------
	**#  Table OA4: Robustness -- clustering
	*---------------------------------------------------------------------------	
	
	
	egen indct = group(ind ct)
	
	cap drop e 
	
	eststo clear
	estimates clear			
	probit constrained_1 comp1_sme_ratio $cont_loc $controls, iter(150) tech(bfgs) vce(cluster GADM_1)
	gen e = e(sample)
	local standarderror `" "cluster GADM_1" "robust" "cluster ind" "cluster ct" "cluster indct" "' 
	foreach se of local standarderror {
		probit constrained_1 comp1_sme_ratio $cont_loc $controls if e==1, iter(150) tech(bfgs) vce(`se')
		mfx	
		outreg2 using "temp.tex", drop($controls) $opts
	}	
	
	filefilter "temp.tex" "temp_1.tex", from(" &  &  &  &  &  \BS\BS") to("") replace	
	filefilter "temp_1.tex" "temp_2.tex", from("VARIABLES") to("") replace	
	filefilter "temp_2.tex" "temp_3.tex", from("\BSbegin{tabular}{lccccc} \BShline") to("") replace	
	filefilter "temp_3.tex" "temp_4.tex", from("Observations") to("\BShline Observations") replace	
	filefilter "temp_4.tex" "TableOA4_clusteredse.tex", from("\BSend{tabular}") to("") replace	
	
	local files : dir "$joeg\Results" files "temp*"
	foreach file in `files' {
		di "`file'"
		cap erase "`file'"
	}	
	
	drop e
		
		
	*---------------------------------------------------------------------------
	**#  Table OA5: Robustness – Varying the size of local banking markets
	*---------------------------------------------------------------------------	

	
	eststo clear
	estimates clear
	foreach type in 7pt5km 10km _pactry31 _pactry35 {
		probit constrained_1 comp1_sme_ratio`type' hhi`type' lerneri_br`type' relbank_`type' lnnr_br`type' $controls, iter(150) tech(bfgs) vce(cluster GADM_1)
		mfx
		outreg2 using "temp.tex", drop($controls) $opts
	}
	
	filefilter "temp.tex" "temp_1.tex", from(" &  &  &  &  \BS\BS") to("") replace	
	filefilter "temp_1.tex" "temp_2.tex", from("VARIABLES") to("") replace	
	filefilter "temp_2.tex" "temp_3.tex", from("\BSbegin{tabular}{lcccc} \BShline") to("") replace	
	filefilter "temp_3.tex" "temp_4.tex", from("7pt5") to("7.5") replace	
	filefilter "temp_4.tex" "temp_5.tex", from("Observations") to("\BShline Observations") replace	
	filefilter "temp_5.tex" "TableOA5_radiversions.tex", from("\BSend{tabular}") to("") replace
	
	local files : dir "$joeg\Results" files "temp*"
	foreach file in `files' {
		di "`file'"
		cap erase "`file'"
	}	
	
	
	*---------------------------------------------------------------------------
	**#  Table OA7: Robustness -- turthfull and  Large city
	*---------------------------------------------------------------------------	

	eststo clear
	estimates clear
	* Only trufull responses
	foreach x in comp1_sme_ratio comp1_smetar_ratio comp1_smeac_ratio {
		probit constrained_1 `x' 		$controls if a16==1|a16==2, iter(150) tech(bfgs) vce(cluster GADM_1)
		mfx
		outreg2 using "temp.tex", drop($controls) $opts					
	}

	* Excluding large cities
	foreach x in comp1_sme_ratio comp1_smetar_ratio comp1_smeac_ratio {
		probit constrained_1 `x' 		$controls if ctsize>2, iter(150) tech(bfgs) vce(cluster GADM_1)
		mfx
		outreg2 using "temp.tex", drop($controls) $opts		
	}
	
	filefilter "temp.tex" "temp_1.tex", from(" &  &  &  &  &  &  \BS\BS") to("") replace	
	filefilter "temp_1.tex" "temp_2.tex", from("VARIABLES") to("") replace	
	filefilter "temp_2.tex" "temp_3.tex", from("\BSbegin{tabular}{lcccccc} \BShline") to("") replace	
	filefilter "temp_3.tex" "temp_4.tex", from("Observations") to("\BShline Observations") replace		
	filefilter "temp_4.tex" "TableOA7_truthfull_largecity.tex", from("\BSend{tabular}") to("") replace	
	
	local files : dir "$joeg\Results" files "temp*"
	foreach file in `files' {
		di "`file'"
		cap erase "`file'"
	}	
	
	
	*---------------------------------------------------------------------------
	**# Table OA8: Robustness -- Locality credit demand
	*---------------------------------------------------------------------------
	
	preserve
	foreach v of var * {
			local l`v' : variable label `v'
				if `"`l`v''"' == "" {
				local l`v' "`v'"
			}
	}	
		
	bys ct city: egen indmode=mode(ind)
	collapse (mean) needed_credit applied_credit /// 
					comp1_sme_ratio comp1_smetar_ratio comp1_smeac_ratio hhi_locbr lnnr_locbr lnnr_locba lerneri_locbr relbank lnnr_br10km  ///
					$controls latitude longitude ind ///
			 (firstnm) indmode , by(ct city)
	
	foreach v of var * {
        label var `v' "`l`v''"
}

	lab var large1 "Large firm (local)"
	lab var public_company "Public firm (local)"
	lab var sole_proprietorship "Proprietorship (local)"
	lab var exporter "Exporter (local)"
	lab var ext_audit "Audited firm (local)"
	lab var old "Mature firm (local)"
	
	eststo clear
	estimates clear
	foreach x in comp1_sme_ratio  { 
		
		reg needed_credit `x' $cont_firm1 ct1-ct19, vce(cluster ct)
		outreg2 using "temp.tex", drop($controls _cons) append tex(fragment) noomitted nobase aster dec(3) rdec(3) nonotes nodepvar ctitle(" ") label
		
		reg needed_credit `x' $controls, vce(cluster ct)
		outreg2 using "temp.tex", drop($controls _cons) append tex(fragment) noomitted nobase  aster dec(3) rdec(3) nonotes nodepvar ctitle(" ") label 
		
		reg needed_credit `x' hhi_locbr  lnnr_br10km   $controls, vce(cluster ct)
		outreg2 using "temp.tex", drop($controls _cons) append tex(fragment) noomitted nobase aster dec(3) rdec(3) nonotes nodepvar ctitle(" ") label 
	
		reg applied_credit `x' $cont_firm1 ct1-ct19, vce(cluster ct)
		outreg2 using "temp.tex", drop($controls _cons) append tex(fragment) noomitted nobase aster dec(3) rdec(3) nonotes nodepvar ctitle(" ") label		
		
		reg applied_credit `x' $controls , vce(cluster ct)
		outreg2 using "temp.tex", drop($controls _cons) append tex(fragment) noomitted nobase  aster dec(3) rdec(3) nonotes nodepvar ctitle(" ") label	
		
		reg applied_credit `x' hhi_locbr  lnnr_br10km   $controls, vce(cluster ct)
		outreg2 using "temp.tex", drop($controls _cons) append tex(fragment) noomitted nobase aster dec(3) rdec(3) nonotes nodepvar ctitle(" ") label
	
	}
	
	filefilter "temp.tex" "temp_1.tex", from(" &  &  &  &  &  &  \BS\BS") to("") replace	
	filefilter "temp_1.tex" "temp_2.tex", from("VARIABLES") to("") replace	
	filefilter "temp_2.tex" "temp_3.tex", from("\BSbegin{tabular}{lcccccc} \BShline") to("") replace	
	filefilter "temp_3.tex" "temp_4.tex", from("Observations") to("\BShline Observations") replace		
	filefilter "temp_4.tex" "TableOA8_localitydemand.tex", from("\BSend{tabular}") to("") replace	
	
	local files : dir "$joeg\Results" files "temp*"
	foreach file in `files' {
		di "`file'"
		cap erase "`file'"
	}
	restore	