	* Close Competitors? Bilateral Bank Competition and Spatial Variation in Firms' Access to Credit
	* Ralph De Haas, Liping Lu and Steven Ongena (2023)	
	
	cls 
	clear

	gl root "" // Update accordingly
	gl joeg "" // Parent folder of "Codes", "Data" and "Results"
	cd "$joeg\Results" // Location to save results
	
	* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
	**# Import data, set globals for regressions and export settings
	* ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~	
	
	use "$joeg/Data/BankPair_INTERNAL.dta"

	ren relrel relrel_sme
	ren trantran trantran_sme

	lab var FF "Foreign i-Foreign j"
	lab var lendsim_sme "(SMEs) Hierarchical efficiency ij"
	lab var lendsim_large "(Large) Hierarchical efficiency ij"

	lab var lev_com "Capitalization j"
	lab var funding_com "Wholesale j"
	lab var intmar_com "Interest margin j"	   

	* Independent variables and fixed effects	
	gl RHS lgnumave overlap lgtotnumave 
	gl ct ct1-ct20
	gl size ssbank llbank
	gl own FF DD
	
	* To export the regressions directly to LaTeX
	gl opts "append tex(fragment) aster dec(3) rdec(3) adec(2) nonotes nodepvar ctitle(" ") label mfx addstat("Pseudo R", e(r2_p))" 
	

	foreach y in sme { 
		   
		eststo clear
		estimates clear
		
		probit select_`y' $RHS 												$ct [pw=weight], cluster(ct) r
		mfx
		outreg2 using "temp.tex", replace drop(ct*) tex(fragment) aster dec(3) rdec(3) adec(2) nonotes nodepvar ctitle(" ") label mfx addstat("Pseudo R", e(r2_p))

		probit select_`y' $RHS $size 										$ct [pw=weight], cluster(ct) r
		mfx
		outreg2 using "temp.tex", drop(ct*) $opts
		
		probit select_`y' $RHS $size $own 									$ct [pw=weight], cluster(ct) r
		mfx
		outreg2 using "temp.tex", drop(ct*) $opts
		
		probit select_`y' $RHS $size $own lev_com funding_com intmar_com 	$ct [pw=weight], cluster(ct) r
		mfx
		outreg2 using "temp.tex", drop(ct*) $opts
		
		probit select_`y' $RHS $size $own focus_`y' 						$ct [pw=weight], cluster(ct) r
		mfx
		outreg2 using "temp.tex", drop(ct*) $opts
		
		probit select_`y' $RHS $size $own lendsim_`y' 						$ct [pw=weight], cluster(ct) r
		mfx
		outreg2 using "temp.tex", drop(ct*) $opts
		
		probit select_`y' $RHS $size $own relrel_`y' trantran_`y' 					$ct [pw=weight], cluster(ct) r
		mfx
		outreg2 using "temp.tex", drop(ct*) $opts
		
		probit select_`y' $RHS $size $own lendsim_`y' relrel_`y' trantran_`y' 		$ct [pw=weight], cluster(ct) r
		mfx
		outreg2 using "temp.tex", drop(ct*) $opts

		filefilter "temp.tex" "temp_1.tex", from(" &  &  &  &  &  &  &  &  \BS\BS") to("") replace	
		filefilter "temp_1.tex" "temp_2.tex", from("VARIABLES") to("") replace	
		filefilter "temp_2.tex" "temp_3.tex", from("\BSbegin{tabular}{lcccccccc} \BShline") to("") replace	
		filefilter "temp_3.tex" "temp_4.tex", from("Observations") to("\BShline Observations") replace		
		filefilter "temp_4.tex" "TableOA2_`y'_bankpair.tex", from("\BSend{tabular}") to("") replace	

		local files : dir "$joeg\Results"files "temp*"
		foreach file in `files' {
			di "`file'"
			cap erase "`file'"
		}
	}


